aboutsummaryrefslogtreecommitdiffstats
path: root/rpc
diff options
context:
space:
mode:
Diffstat (limited to 'rpc')
-rw-r--r--rpc/ipc.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/rpc/ipc.go b/rpc/ipc.go
index b05e503d7..1467f7a0c 100644
--- a/rpc/ipc.go
+++ b/rpc/ipc.go
@@ -24,17 +24,17 @@ import (
"github.com/ethereum/go-ethereum/p2p/netutil"
)
// ServeListener accepts connections on l, serving JSON-RPC on them.
func (srv *Server) ServeListener(l net.Listener) error {
for {
conn, err := l.Accept()
if netutil.IsTemporaryError(err) {
- log.Warn("RPC accept error", "err", err)
+ log.Warn("IPC accept error", "err", err)
continue
} else if err != nil {
return err
}
- log.Trace("Accepted connection", "addr", conn.RemoteAddr())
+ log.Trace("IPC accepted connection")
go srv.ServeCodec(NewJSONCodec(conn), OptionMethodInvocation|OptionSubscriptions)
}
}
@@ -24,17 +24,17 @@ import (
"github.com/ethereum/go-ethereum/p2p/netutil"
)
-// ServeListener accepts connections on l, serving JSON-RPC on them.
+// ServeListener accepts connections on l, serving IPC-RPC on them.
func (srv *Server) ServeListener(l net.Listener) error {
for {